@@ -225,6 +225,14 @@ public:
 	static void setDebug(bool mode)
 		{_debug = mode;};
 
+	/**
+	 * Enable setting of mutex name for deadlock debug.
+	 *
+	 * @param name for mutex.
+	 */
+	inline void nameMutex(const char *cp)
+		{_name = cp;};
+
 	/**
 	 * Entering a Mutex locks the mutex for the current thread.  This
 	 * also can be done using the ENTER_CRITICAL macro or by using the
